@@ -1,6 +1,6 @@
 <?php
 
-# Pages config file for FitGallery 0.94
+# Pages config file for FitGallery 0.95
 # under public domain
 
 # In order to get specific configuration for some pages, you can copy
@@ -11,7 +11,6 @@
 
 $titulo='titulo';              # name of text/psuedoHTML-PHP files with galleries titles
 $subtitulo='subtitulo';        # name of text/psuedoHTML-PHP files with galleries subtitles
-$npages_user=true;             # let the user specify the number of thumbs per page
 $def_avance=12;                # number of thumbs per page by default if not specified by user
 $max_avance=100;               # max number of thumbs per page allowed
 $remote_espace=true;           # Espaces for remote old galleries (without number, size and date info)
@@ -24,7 +23,7 @@ $print_totals=true;            # Print total bytes at bottom
 $style='random.css.php';       # Style sheet for pages
 #$lang='es';                    # language, only support at this moment 'es' (spanish)
 $lang='en';                    # and 'en' (english)
-$charset='ISO-8859-1';         # charset used on pages, alternatives: US-ASCII, UTF-8
+$charset='US-ASCII';           # charset used on pages, alternatives: ISO-8859-1, UTF-8
 $date_string='Y-m-d H:i:s';    # Date format (php specification for date() function), ISO by default
 $w3logo=true;                  # show W3C logo
 $powered=true;                 # show 'powered by FitGallery' message
