@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.94
+# FitGallery 0.95
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -28,7 +28,7 @@ include 'config/config-pages.php';
 include 'config/config-common.php';
 
 $file=check_input($_GET['valor'],VALID_CHARS);
-if (!$file) exit_error('Remote gallery not found.');
+if ($file=='') exit_error('Remote gallery not found.');
 $dirimgs='imgs';
 
 header('Content-type: text/plain');
