@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.94
+# FitGallery 0.95
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -42,12 +42,12 @@ function thumbnail ($galeria,$fichero,$tipo)
     case 'm': $rutathumbs=$dg.'/medium';
               $calidad=$quality_medium;
               $resample=$resample_medium;
-              $altura=$h_medium;
+              if (!$altura=$h_medium) exit_error('Medium thumbnails disabled.');
               break;
     case 't': $rutathumbs=$dg.'/thumbs';
               $calidad=$quality_thumb;
               $resample=$resample_thumb;
-              $altura=$h_thumb;
+              if (!$altura=$h_thumb) exit_error('Thumbnails disabled.');
               break;
     default: exit_error('Bad thumbnail type.');
   }
@@ -69,8 +69,7 @@ function thumbnail ($galeria,$fichero,$tipo)
       if (($size=getimagesize($imagen))==false )
           exit_error('Source image corrupted or not supported.');
       $stipo=$size[2];
-      if ($stipo==IMAGETYPE_JPEG)
-        if ($show_exif_thumbs)
+      if ($show_exif_thumbs && $stipo==IMAGETYPE_JPEG && $tipo=='t')
           if (exif_thumbnail($imagen))
           {
             location("exif_thumb.php?img=$fichero&galeria=$galeria");
