@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.94
+# FitGallery 0.95
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -36,7 +36,7 @@ include 'config/config-lang.php';
 $galeria=check_input($_GET['galeria'],VALID_CHARS);
 if ($galeria=='') exit_error('Missing argument.');
 
-if ($npages_user)
+if ($tpp_pos!='none')
  {
    $avance=check_input($_GET['avance'],'number');
    if ($avance>$max_avance) $avance=$max_avance;
@@ -116,7 +116,7 @@ $numer_pagmasuno=$numer_pag+1;
 
 # Generate navigator array
 
-for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pagmasuno; $i++)
+for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pagmasuno; $i++, $cuentaant=$cuenta+1, $cuenta=$cuenta+$avance)
 {
    if ($cuentaant!=$desde)
      {
@@ -127,8 +127,6 @@ for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pagmasuno; $i++)
    $arrnav[$i]['cua']=$cuentaant;
    if ($cuenta>$numero_arch) $arrnav[$i]['cu']=$numero_arch;
    else $arrnav[$i]['cu']=$cuenta;
-   $cuentaant=$cuenta+1;
-   $cuenta=$cuenta+$avance;
 }
 
 $anterior=$para-$avance;
@@ -144,7 +142,7 @@ if ($nav_pos=='top' || $nav_pos=='both')
 
       # Print top number-of-thumbnails-per-page form
 if ($tpp_pos=='top' || $tpp_pos=='both')
-    html_thpp_form($npages_user,$text_thpp,$avance,$text_change,$galeria);
+    html_thpp_form($text_thpp,$avance,$text_change,$galeria);
 
 html_sep();
 
@@ -164,7 +162,7 @@ if ($nav_pos=='bottom' || $nav_pos=='both')
 
       # Print bottom number-of-thumbnails-per-page form
 if ($tpp_pos=='bottom' || $tpp_pos=='both')
-    html_thpp_form($npages_user,$text_thpp,$avance,$text_change,$galeria);
+    html_thpp_form($text_thpp,$avance,$text_change,$galeria);
 
 html_end($text_totales,$total,$totalmegas,$powered,$text_powered,$version,$print_totals,$w3logo);
 
@@ -272,9 +270,9 @@ function html_image($ruta,$galeria,$h_medium,$text_medium,$h_thumb,$i,$valor,$si
 }
 
 
-function html_thpp_form($npages_user,$text_thpp,$avance,$text_change,$galeria)
+function html_thpp_form($text_thpp,$avance,$text_change,$galeria)
 {
-if ($npages_user) echo "
+echo "
 <form class=\"tpp\" action=\"ver_thumb.php\" method=\"get\">
 <p class=\"normal\">
 $text_thpp <input class=\"tppin\" type=\"text\" name=\"avance\" value=\"$avance\" size=\"3\" maxlength=\"3\">
